Credits
=======

This package is primarily written by `Justin Bois <http://bois.caltech.edu>`_ for use in the `BE/Bi 103 a <https://bebi103a.github.io/>`_ and `BE/Bi 103 b <https://bebi103b.github.io/>`_ courses at `Caltech <http://caltech.edu/>`_.


Citing bebi103
==================

Because this package evolves according to the needs of the BE/Bi 103 ab courses, it has at best a stable-ish API. It is therefore very important to include a version number when citing the package. It is best to cite the package using its DOI. Here is a citation for version 0.1.0.

.. code-block:: bibtex

    @misc{#10.22002/D1.1615,
      doi = {10.22002/D1.1615},
      url = {https://doi.org/10.22002/D1.1615},
      author = {Bois, Justin S.},
      keywords = {Github},
      title = {justinbois/bebi103: Version 0.1.0},
      publisher = {CaltechDATA},
      year = {2020}
    }
